@@ -1,5 +1,4 @@
 import io
-from datetime import datetime
 
 import pkg_resources
 from PIL import Image, ImageDraw, ImageFont, ImageOps
@@ -10,12 +9,12 @@ FONT_SIZE = 16
 FONT = pkg_resources.resource_filename(__name__, 'resources/font.ttf')
 
 
-def draw_date(draw: ImageDraw, date: datetime):
+def draw_date(draw, date):
     font = ImageFont.truetype(FONT, FONT_SIZE)
     draw.text((10, 30), date.strftime("%d-%m-%Y"), font=font, fill=(0, 0, 0))
 
 
-def draw_longstring(draw: ImageDraw, name: str, position: tuple):
+def draw_longstring(draw, name, position):
     font = ImageFont.truetype(FONT, FONT_SIZE)
 
     font_size = FONT_SIZE
@@ -27,7 +26,7 @@ def draw_longstring(draw: ImageDraw, name: str, position: tuple):
     draw.text(position, name, font=font, fill=(0, 0, 0))
 
 
-def convert(name: str, date: datetime, a_hash: str) -> io.BytesIO:
+def convert(name, date, a_hash):
     img_without_border = Image.new('RGB', (WIDTH, HEIGHT), color=(255, 255, 255))
     img = ImageOps.expand(img_without_border, border=1, fill="black")
 
