@@ -1,13 +1,11 @@
-from datetime import datetime
-from typing import BinaryIO
+import io
 
 import PyPDF2
-import io
 
 import signer_pdf.sign_generator as sign_generator
 
 
-def sign(name: str, date: datetime, a_hash: str, in_file: BinaryIO) -> io.BytesIO:
+def sign(name, date, a_hash, in_file):
     bs = sign_generator.convert(name, date, a_hash)
     original = PyPDF2.PdfFileReader(in_file)
     last_page = original.getPage(original.getNumPages() - 1)
